@@ -50,7 +50,7 @@ case "$1" in
 
         if [ -e /usr/share/apache2/apache2-maintscript-helper ];then
             # Debian Jessie / Apache2.4
-            mkdir -p /etc/apache2/conf-available
+            [ -d /etc/apache2/conf-available ] || mkdir -p /etc/apache2/conf-available
             ln -sf /etc/benno-web/apache-2.4.conf /etc/apache2/conf-available/benno.conf
             . /usr/share/apache2/apache2-maintscript-helper
             apache2_invoke enconf benno
@@ -59,25 +59,31 @@ case "$1" in
             ln -sf /etc/benno-web/apache-2.2.conf /etc/apache2/conf.d/benno
         fi
 
-        # upgrade port settings
-        set +e
-        grep -q localhost:8080 /etc/benno-web/benno.conf 2>/dev/null
-        if [ $? -eq 0 ];then
-            perl -p -i -e 's/localhost:8080$/localhost:21080/' /etc/benno-web/benno.conf
-        else
-            BASEURL=`grep BASE_URL /etc/benno-web/benno.conf 2>/dev/null`
-            echo ""
-            echo ""
-            echo "################################################################"
-            echo "#  ACHTUNG! Bitte die Host- und Portkonfigurationen von"
-            echo "#    /etc/benno-web/benno.conf: ${BASEURL}"
-            echo "#  und"
-            echo "#    /etc/benno/jetty.xml: \"host\" und \"port\""
-            echo "#  vergleichen und gegebenenfalls anpassen."
-            echo "################################################################"
-        fi
-        set -e
+        ## upgrade port settings
+        #set +e
+        #grep -q localhost:8080 /etc/benno-web/benno.conf 2>/dev/null
+        #if [ $? -eq 0 ];then
+        #    perl -p -i -e 's/localhost:8080$/localhost:21080/' /etc/benno-web/benno.conf
+        #else
+        #    BASEURL=`grep BASE_URL /etc/benno-web/benno.conf 2>/dev/null`
+        #    echo ""
+        #    echo ""
+        #    echo "################################################################"
+        #    echo "#  ACHTUNG! Bitte die Host- und Portkonfigurationen von"
+        #    echo "#    /etc/benno-web/benno.conf: ${BASEURL}"
+        #    echo "#  und"
+        #    echo "#    /etc/benno/jetty.xml: \"host\" und \"port\""
+        #    echo "#  vergleichen und gegebenenfalls anpassen."
+        #    echo "################################################################"
+        #fi
+        #set -e
 
+        # Auto-Create password
+        if [ ! -f /etc/benno/rest.secret ];then
+            openssl rand -hex 20 > /etc/benno/rest.secret
+            echo -n 'SHARED_SECRET = '  > /etc/benno-web/rest.conf
+            cat /etc/benno/rest.secret >> /etc/benno-web/rest.conf
+        fi
 
     ;;
 
