@@ -203,7 +203,7 @@ if (file_exists($MODULE.'/post_view.php')) {
 }
 
 /* Check template authorization */
-if ($App->getConfig('TEMPLATE_AUTHZ') &! $App->authz($App->view)) {
+if ($App->getConfig('TEMPLATE_AUTHZ',true) &! $App->authz($App->view)) {
     // authzError
     $App->log("ERR_AUTHZ Template: $App->view.tpl",0,'SPAF2');
     $App->view = 'error';
