@@ -674,7 +674,11 @@ class Application extends ApplicationConfig
      */
     function redirect ($action,$plist=array())
     {
-        $params = session_name().'='.session_id().'&CA='.$action;
+        if ($this->getConfig('URL_SESSIONID') == 'ENABLED') {
+            $sidprefix = session_name().'='.session_id().'&';
+        }
+        $params = $sidprefix.'CA='.$action;
+
         if (is_array($plist)) {
             foreach ($plist as $var => $value) {
                 $params .= '&'.$var.'='.$value;
