@@ -82,7 +82,7 @@ class ApplicationConfig
      * @param string $file relative to configdir
      * @return array $parameters
      */
-    function load ($file)
+    function load ($file,$die_on_error=true)
     {
         $this->parameters = '';
         $cfile = $this->configdir .'/'. $file;
@@ -91,7 +91,12 @@ class ApplicationConfig
             $dir = $_SERVER['SCRIPT_FILENAME'];
             $script_path = dirname($dir);
 	        error_log('Cannot open config file: '.$script_path. '/'.$cfile);
-            die ("Cannot open config file.\n");
+            if ($die_on_error) {
+                die ("Cannot open config file.\n");
+            }
+            else {
+                return $this->parameters;
+            }
         }
         $env = array();
         foreach (array('BASE_URL') as $varname) {
@@ -118,15 +123,22 @@ class ApplicationConfig
     /**
      * Fetch message
      *
-     * DEPREACHED! Compatibility method.
-     * 
      * @access public
-     * @return string $message
      * @param string $name
+     * @param string $default (optional)
+     * @return string $message
      */
-    function getConfig ($name)
+    function getConfig ($name,$default=false)
     {
-        return $this->parameters[$name];
+        if (isset($this->parameters[$name])) {
+            return  $this->parameters[$name];
+        }
+        else if ($default) {
+            return $default;
+        }
+        else {
+            return false;
+        }
     }
 
     /**
@@ -136,9 +148,9 @@ class ApplicationConfig
      * @return string $message
      * @param string $name
      */
-    function get($name)
+    function get($name,$default=false)
     {
-        return $this->parameters[$name];
+        return $this->getConfig($name,$default);
     }
 
 
