@@ -49,8 +49,7 @@ try {
     $QueryResult = $Backend->query($archive,$SimpleQuery,0,$search_limit);
     // clear flag
     $App->unsetSession('ENABLE_CACHE_WARMING_REQUEST');
-    print $QueryResult->numAll();
-    exit;
+    $App->response($QueryResult->numAll(),'text/plain');
 }
 catch (Exception $e) {
     $App->log('[a_cachereq] '.$e->getMessage(),3);
