@@ -36,8 +36,6 @@ require_once 'model/DateConvert.php';
 require_once 'model/Filter.php';
 require_once 'model/AppState.php';
 
-
-$base_url    = $App->getConfig('BASE_URL');
 $authscript  = $App->getConfig('EXTERNAL_AUTH');
 
 $login = $App->getParam('login');
@@ -81,7 +79,17 @@ $filterString = '';
 foreach ($FilterList as $Filter) {
     $filterString .= $Filter->getString();
 }
-$Backend = new Backend($base_url,$filterString);
+
+$RESTconf = new ApplicationConfig($App->configdir);
+$RESTconf->load($App->getConfig('REST_CONFIG','rest.conf'),false);
+
+// defaults: compatibility to deprecated configuration
+$base_url_mainconf = $App->getConfig('BASE_URL','http://localhost:21080');
+$base_url  = $RESTconf->getConfig('BASE_URL',$base_url_mainconf);
+$rest_user = $RESTconf->getConfig('REST_USER','benno2');
+$rest_pass = $RESTconf->getConfig('SHARED_SECRET',$App->getConfig('SHARED_SECRET'));
+
+$Backend = new Backend($base_url,$rest_user,$rest_pass,$filterString);
 
 // initialize session
 $App->setSession('ACCESS_LEVEL',$User->getAuthzLevel());
