@@ -82,9 +82,11 @@ class Backend
 
         $EMail = new EMail($sessionMailId,$archive,$bennoId,$header['From'],$header['To'],$header['Cc'],$header['Bcc'],$header['Subject'],$header['Date'],$header['Size'],$body);
         $EMail->verified = $header['X-Benno-HashCheckPassed'];
+        $EMail->dateTS   = $header['X-Benno-DateTS'];
 
         foreach ($maildata['attachments'] as $atm) {
-            $Attachment = new Attachment($atm['name'],@$atm['content-type'], $atm['size']);
+            //$Attachment = new Attachment($atm['name'],@$atm['content-type'], $atm['size']);
+        	$Attachment = new Attachment($atm['name'],@$atm['content-type'], $atm['size'], true, $atm['attachmentId']);
             $EMail->addAttachment($Attachment);
         }
 
@@ -149,7 +151,7 @@ class Backend
      * @param string $mailId
      * @return object $EMail
      */
-    function fetchAttachment ($archive,$sessionMailId,$filename)
+    function fetchAttachment ($archive,$sessionMailId,$filename, $attachmentId = '')
     {
         $bennoId = QueryResult::getBennoId($sessionMailId);
 
@@ -157,6 +159,9 @@ class Backend
         $query_string = 'archive='.$archive.
                         '&id='.$bennoId.
                         '&attachment='.$filename;
+                        
+	    if($attachmentId != "")         
+	      $query_string .= '&attachmentId='.$attachmentId;
 
         $file = $this->_curl_query($request_url,$query_string,'raw');
         if (! $file) {
@@ -184,7 +189,7 @@ class Backend
             $App->log('[Backend/fetchLicense] No valid License found');
         }
 
-        $License = new License($data['licenseStatus'],$data['licenseExpires'],$data['licenseType'],$data['licenseFile'],$data['myAddress'],$data['myHostname'],$data['buildInfo']);
+        $License = new License($data['licenseStatus'],$data['licenseExpires'],$data['licenseType'],$data['licenseFile'],$data['myAddress'],$data['myHostname'],$data['buildInfo'],$data['coreVersion'],$data['restVersion']);
 
         return $License;
     }
