@@ -81,9 +81,10 @@ class EMail
     var $hasAttachment;
     var $attachments;
     var $verified;
+    var $dateTS;
 
 
-    function EMail ($id,$archive,$bennoId='',$from='',$to=array(),$cc=array(),$bcc=array(),$subject='',$date='',$size='',$body='',$hasAttachment=false,$verified=false)
+    function EMail ($id,$archive,$bennoId='',$from='',$to=array(),$cc=array(),$bcc=array(),$subject='',$date='',$size='',$body='',$hasAttachment=false,$verified=false,$dateTS=0)
     {
         $this->id       = $id; 
         $this->archive  = $archive; 
@@ -106,6 +107,7 @@ class EMail
 
         $this->attachments = array();
         $this->verified = $verified;
+        $this->dateTS = $dateTS;
     }
 
     /**
@@ -116,7 +118,11 @@ class EMail
      */
     function getDate ()
     {
-        return strtotime($this->date);
+        $retDate = strtotime($this->date);
+        if (!$retDate) {
+            $retDate = $this->dateTS;
+        }
+        return $retDate;
     }
 
 
