@@ -78,7 +78,7 @@ class License
     /**
      * Hostname 
      */
-    var $hostnaem;
+    var $hostname;
 
 
     /**
@@ -93,12 +93,26 @@ class License
     var $restbuild;
 
 
+    /**
+     * CORE version
+     */
+    var $coreVersion;
+
+
+    /**
+     * REST version
+     */
+    var $restVersion;
+
+
+
+
     /**
      * Constructor
      *
      * @access public
      */
-    function License ($licenseStatus,$licenseExpires,$licenseType,$licenseFile,$address,$hostname,$restbuild)
+    function License ($licenseStatus,$licenseExpires,$licenseType,$licenseFile,$address,$hostname,$restbuild,$coreVersion,$restVersion)
     {
 
         if (preg_match('/^LICENSE_VALID/',$licenseStatus)) {
@@ -118,6 +132,9 @@ class License
         $this->restbuild = $restbuild;
         $this->_licenseFile = $licenseFile;
 
+        $this->coreVersion = $coreVersion;
+        $this->restVersion = $restVersion;
+
         $lines = preg_split('/\n/',$licenseFile);
         foreach ($lines as $line) {
 
