@@ -58,10 +58,11 @@ $MailObject->verified   = $EMail->isVerified();
 
 $atm_list = array();
 foreach ($EMail->getAttachments() as $Attachment) {
-    $atm['id']      = $Attachment->id;
-    $atm['type']    = $Attachment->type;
-    $atm['size']    = $Attachment->size;
-    $atm['icon']    = $Attachment->getIcon();
+    $atm['id']           = urlencode($Attachment->id);
+    $atm['attachmentId'] = $Attachment->attachmentId;
+    $atm['type']         = $Attachment->type;
+    $atm['size']         = $Attachment->size;
+    $atm['icon']         = $Attachment->getIcon();
     array_push($atm_list,$atm);
 }
 $MailObject->attachments= $atm_list;
